home | help
XWALLPAPER(1)		     General Commands Manual		   XWALLPAPER(1)

NAME
     xwallpaper -- wallpaper setting utility for X

SYNOPSIS
     xwallpaper [--screen screen] [--clear] [--daemon] [--debug] [--no-atoms]
		[--no-randr] [--no-root] [--trim widthxheight[+x+y]]
		[--output output] [--center file] [--focus file]
		[--maximize file] [--stretch file] [--tile file] [--zoom file]
		[--version]

DESCRIPTION
     The  xwallpaper  program allows you to set image files as your X wallpaper.
     PNG file format is supported by default and preferred,  but  optional  JPEG
     support exists as well.

     The wallpaper is also advertised to programs which support semi-transparent
     backgrounds.

OPTIONS
     The various options are as follows:

     --center file
	     Centers the input file on the output.  If the dimensions of the in-
	     put file are smaller than the output dimensions, the remaining area
	     is filled black.  If the input file dimensions are too large, parts
	     of the image will be cropped.

     --clear
	     Initializes screen with a black background. Without this option the
	     current  content of pseudo transparency atoms is retrieved and used
	     as foundation.  If atom contents do not exist or cannot be  reused,
	     e.g.  due	to resolution change of one of the outputs, then an ini-
	     tially black background is used as well.

     --daemon
	     Keeps xwallpaper running in background, listening for RandR events.
	     In this mode, the wallpapers are redrawn when output sizes  change.
	     This  option  can	only be used when RandR support is available and
	     activated.

     --debug
	     Displays  debug  messages	on  the  standard  error  output   while
	     xwallpaper  is  running.	If used in conjunction with --daemon the
	     process will not modify the standard input and outputs.

     --focus file
	     In conjunction with --trim the specified trim box will  be  guaran-
	     teed  to be visible on output, zooming out if needed. If black pix-
	     els would occur around the selection, the input image is zoomed  in
	     and moved to cover them as good as possible under the constraint of
	     keeping  the  specified trim box (or whole image if no trim box has
	     been specified) on output.

     --maximize file
	     Maximizes input file to fit output without  cropping.   This  could
	     mean  zooming  in	or out, depending on the dimensions of the input
	     file and the output.  This option guarantees that the  whole  image
	     is  seen.	If the ratio does not fit the output, the remaining area
	     is filled black.  The image itself will be centered on output.

     --no-atoms
	     Atoms which are used for pseudo transparency are not updated. Mutu-
	     ally exclusive with --no-root option. Automatically enables --clear
	     option.

     --no-randr
	     Ignores individual outputs and uses the whole output instead.  This
	     is the area that spans across all different outputs (monitors).

     --no-root
	     The background of the root window is not updated. Use  this  option
	     if  you  want to update only atoms used for pseudo transparency. It
	     is therefore mutually exclusive with --no-atoms option.

     --trim widthxheight+x+y
	     Specifies area of interest in source file. If output mode tries  to
	     output  more pixels than specified with trim box, then the adjacent
	     pixels around the box will be added to  output.  Black  pixels  are
	     only added if no further source pixels are left.

     --output output
	     Specifies the output on which a subsequently supplied file shall be
	     set  as wallpaper.  You can retrieve a list of outputs on your sys-
	     tem by executing xrandr(1).  If no output is specified, all outputs
	     will be modified individually.  The special keyword all will repeat
	     subsequent actions on all displays.  If the  output  could  not  be
	     found, its associated actions are ignored.

     --screen screen
	     Specifies	a  screen by its screen number.  Normally all screens of
	     an X display are processed.  Please note that a  screen  is  not  a
	     single monitor.  See --output for such a use case above.

     --stretch file
	     Stretches	input file to fully cover the output.  If the aspect ra-
	     tio of the input file does not match the output, then the ratio  of
	     the input file is adjusted.

     --tile file
	     Uses tiling mode.	Draws the input file at the upper left corner of
	     the  output  and  repeats the image until the remaining area of the
	     output is covered.

     --version
	     Prints version and exits.

     --zoom file
	     Zooms input file to fit output  with  cropping.   This  could  mean
	     zooming  in  or  out, depending on the dimensions of the input file
	     and the output.  If the ratio does not fit the output, parts of the
	     input file will not be shown.  The image itself will be centered on
	     output.  Default behaviour if no option was selected.

     If multiple contradicting options were  given,  the  last	supplied  option
     wins.   It  is  also possible to repeat output arguments without any subse-
     quent files.  In that case, the last mode and file will be reused.

EXAMPLES
     Centers a PNG file as a wallpaper on LVDS-1:
	   $ xwallpaper --output LVDS-1 --center file.png

     Focuses on upper left corner of a JPEG file as a wallpaper on Virtual-1:
	   $ xwallpaper --output Virtual-1 --trim 1x1+0+0 --focus file.jpg

     Tiles a PNG file as a wallpaper across all outputs:
	   $ xwallpaper --no-randr --tile file.png

     Zooms into a JPEG file as a wallpaper on each output individually:
	   $ xwallpaper --zoom file.jpg

     Centers and recenters a JPEG file after output updates on all outputs:
	   $ xwallpaper --daemon --center file.jpg

     Tiles a JPEG file as a wallpaper on VGA-1 and zooms  into	a  PNG	file  on
     LVDS-1:
	   $  xwallpaper  --output  VGA-1 --tile file.jpg --output LVDS-1 --zoom
	   file.png

BUGS
     Use	    the 	   GitHub	      issue		tracker:
     https://github.com/stoeckmann/xwallpaper/issues

AUTHOR
     Tobias Stockmann <tobias@stoeckmann.org>

xwallpaper 0.7.4		  June 30, 2022 		   XWALLPAPER(1)

home | help